@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Roles::List;
 
 BEGIN {
-    $WWW::Google::Contacts::Roles::List::VERSION = '0.14';
+    $WWW::Google::Contacts::Roles::List::VERSION = '0.15';
 }
 
 use Moose::Role;
@@ -58,7 +58,7 @@ sub search {
     my $to_ret = [];
   ELEM:
     foreach my $elem ( @{ $self->elements } ) {
-        my $obj = $class->new();
+        my $obj = $class->new( server => $self->server );
         $obj->set_from_server($elem);
         foreach my $key ( keys %{$search} ) {
             next ELEM unless ( defined $obj->$key );
