@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Type::IM;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::IM::VERSION = '0.14';
+    $WWW::Google::Contacts::Type::IM::VERSION = '0.15';
 }
 
 use Moose;
@@ -20,6 +20,14 @@ has type => (
     coerce    => 1,
 );
 
+has label => (
+    isa       => Str,
+    is        => 'rw',
+    traits    => ['XmlField'],
+    xml_key   => 'label',
+    predicate => 'has_label',
+);
+
 has protocol => (
     isa       => Rel,
     is        => 'rw',
